autowisp.fit_expression.FitTermsLexer module — AutoWISP documentation

# autowisp.fit_expression.FitTermsLexer module

## Class Inheritance Diagram

class autowisp.fit_expression.FitTermsLexer.FitTermsLexer(input=None, output: ~typing.TextIO = <_io.TextIOWrapper name='<stdout>' mode='w' encoding='utf-8'>)

  Bases: `Lexer`

  CROSSPRODUCT = 4
  POLY_START = 3
  TERM = 9
  TERM_LIST = 1
  TERM_LIST_END = 7
  TERM_LIST_START = 1
  TERM_SEP = 8
  UINT = 2
  UNION = 5
  WS = 6
  atn = <antlr4.atn.ATN.ATN object>
  channelNames = ['DEFAULT_TOKEN_CHANNEL', 'HIDDEN']
  decisionsToDFA = [<antlr4.dfa.DFA.DFA object>, <antlr4.dfa.DFA.DFA object>, <antlr4.dfa.DFA.DFA object>, <antlr4.dfa.DFA.DFA object>]
  grammarFileName = 'FitTermsLexer.g4'
  literalNames = ['<INVALID>', "'{'", "'O'", "'*'", "'+'", "'}'", "','"]
  modeNames = ['DEFAULT_MODE', 'TERM_LIST']
  ruleNames = ['TERM_LIST_START', 'UINT', 'POLY_START', 'CROSSPRODUCT', 'UNION', 'WS', 'TERM_LIST_END', 'TERM_SEP', 'TERM', 'TERMCHAR']
  symbolicNames = ['<INVALID>', 'TERM_LIST_START', 'UINT', 'POLY_START', 'CROSSPRODUCT', 'UNION', 'WS', 'TERM_LIST_END', 'TERM_SEP', 'TERM']

autowisp.fit_expression.FitTermsLexer.serializedATN()